@@ -8,5 +8,12 @@
 </div>
 <?php do_action('admin_footer', ''); ?>
 <script type="text/javascript">if(typeof wpOnload=='function')wpOnload();</script>
+
+<?php
+if ( (substr(php_sapi_name(), 0, 3) == 'cgi') && spawn_pinger() ) {
+	echo '<iframe id="pingcheck" src="' . get_settings('siteurl') .'/wp-admin/execute-pings.php?time=' . time() . '" style="border:none;width:1px;height:1px;"></iframe>';
+}
+?>
+
 </body>
-</html>
\ No newline at end of file
+</html>
